@@ -1,7 +1,7 @@
 package Module::DataPack;
 
-our $DATE = '2015-10-03'; # DATE
-our $VERSION = '0.11'; # VERSION
+our $DATE = '2015-10-11'; # DATE
+our $VERSION = '0.12'; # VERSION
 
 use 5.010001;
 use strict;
@@ -29,8 +29,8 @@ the modules' source codes are put in `__DATA__` section instead of regular Perl
 hashes (fatpack uses `%fatpacked`). This reduces compilation overhead, although
 this is not noticeable unless when the number of embedded modules is quite
 large. For example, in `App::pause`, the `pause` script embeds ~320 modules with
-a total of ~54000 lines. The overhead of fatpack code is about 49ms, while with
-datapack the overhead is about XXX ms.
+a total of ~54000 lines. The overhead of fatpack code is ~49ms on my PC, while
+with datapack the overhead is about ~10ms.
 
 There are two downsides of this technique. The major one is that you cannot load
 modules during BEGIN phase (e.g. using `use`) because at that point, DATA
@@ -244,7 +244,7 @@ Module::DataPack - Like Module::FatPack, but uses datapacking instead of fatpack
 
 =head1 VERSION
 
-This document describes version 0.11 of Module::DataPack (from Perl distribution Module-DataPack), released on 2015-10-03.
+This document describes version 0.12 of Module::DataPack (from Perl distribution Module-DataPack), released on 2015-10-11.
 
 =head1 SEE ALSO
 
@@ -267,8 +267,8 @@ the modules' source codes are put in C<__DATA__> section instead of regular Perl
 hashes (fatpack uses C<%fatpacked>). This reduces compilation overhead, although
 this is not noticeable unless when the number of embedded modules is quite
 large. For example, in C<App::pause>, the C<pause> script embeds ~320 modules with
-a total of ~54000 lines. The overhead of fatpack code is about 49ms, while with
-datapack the overhead is about XXX ms.
+a total of ~54000 lines. The overhead of fatpack code is ~49ms on my PC, while
+with datapack the overhead is about ~10ms.
 
 There are two downsides of this technique. The major one is that you cannot load
 modules during BEGIN phase (e.g. using C<use>) because at that point, DATA
@@ -277,7 +277,7 @@ section is not yet available. You can only use run-time require()'s.
 Another downside of this technique is that you cannot use C<__DATA__> section for
 other purposes (well, actually with some care, you still can).
 
-This function is not exportable.
+This function is not exported by default, but exportable.
 
 Arguments ('*' denotes required arguments):
 
